@@ -113,7 +113,7 @@
 
     [
         name              => 'Master',
-        experience        => [ [qw/tree_macro warp/] => 'advanced' ],
+        experience        => [ [qw/warp/] => 'advanced' ],
         class_description => "
 
 =head1 coucou
@@ -145,6 +145,29 @@ things.
             },
         ],
         element => [
+            tree_macro => {
+                type       => 'leaf',
+                value_type => 'enum',
+                choice     => [qw/XY XZ mXY/],
+                help       => {
+                    XY  => 'XY help',
+                    XZ  => 'XZ help',
+                    mXY => 'mXY help',
+                }
+            },
+            pop_in_out => {
+                type       => 'leaf',
+                level => 'hidden',
+                value_type => 'uniline',
+                default    => 'yada yada',
+                warp => {  
+                    follow            => '! tree_macro',
+                    rules             => [
+                        XZ => { level => 'normal' },
+                    ],
+                },
+            },
+
             std_id => {
                 type       => 'hash',
                 index_type => 'string',
@@ -212,16 +235,6 @@ things.
                     choice     => [qw/A B C/],
                 }
             },
-            tree_macro => {
-                type       => 'leaf',
-                value_type => 'enum',
-                choice     => [qw/XY XZ mXY/],
-                help       => {
-                    XY  => 'XY help',
-                    XZ  => 'XZ help',
-                    mXY => 'mXY help',
-                }
-            },
             warp => {
                 type              => 'warped_node',
                 follow            => '! tree_macro',
